@@ -1,15 +1,6 @@
 ################################################################################
-#
-# $Project: /Tie-Hash-Indexed $
-# $Author: mhx $
-# $Date: 2003/11/11 21:42:36 +0100 $
-# $Revision: 4 $
-# $Snapshot: /Tie-Hash-Indexed/0.04 $
-# $Source: /lib/Tie/Hash/Indexed.pm $
-#
-################################################################################
 # 
-# Copyright (c) 2002-2003 Marcus Holland-Moritz. All rights reserved.
+# Copyright (c) 2002-2016 Marcus Holland-Moritz. All rights reserved.
 # This program is free software; you can redistribute it and/or modify
 # it under the same terms as Perl itself.
 # 
@@ -17,12 +8,13 @@
 
 package Tie::Hash::Indexed;
 use 5.004;
+use strict;
 use DynaLoader;
 use Tie::Hash;
 use vars qw($VERSION @ISA);
 
 @ISA = qw(DynaLoader Tie::Hash);
-$VERSION = do { my @r = '$Snapshot: /Tie-Hash-Indexed/0.04 $' =~ /(\d+\.\d+(?:_\d+)?)/; @r ? $r[0] : '9.99' };
+$VERSION = '0.06';
 
 bootstrap Tie::Hash::Indexed $VERSION;
 
@@ -90,7 +82,7 @@ If you're interested in what I currently plan to improve
 
 =head1 COPYRIGHT
 
-Copyright (c) 2003 Marcus Holland-Moritz. All rights reserved.
+Copyright (c) 2003-2016 Marcus Holland-Moritz. All rights reserved.
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
